##  Detailed View
The detailed view allows you to customize relations, subscriptions, tag groups, resources management and displaying any other additional fields in the details view.
**Note**
When you enable the Show diagrams from SAP LeanIX fact sheets toggle, only diagrams under the heading Linked diagrams are shown as resources. Diagrams under the heading Diagrams with this fact sheet are not shown.
Detailed view in Portals Configuration ![Portal configuration screen showing detailed view settings in SAP LeanIX.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3230057edc0445348651c443db257d6a_LowRes.png)
